summaryrefslogtreecommitdiff
path: root/sql/sp_pcontext.h
diff options
context:
space:
mode:
Diffstat (limited to 'sql/sp_pcontext.h')
-rw-r--r--sql/sp_pcontext.h17
1 files changed, 6 insertions, 11 deletions
diff --git a/sql/sp_pcontext.h b/sql/sp_pcontext.h
index bd2259cb6fb..b8dd1742f7e 100644
--- a/sql/sp_pcontext.h
+++ b/sql/sp_pcontext.h
@@ -170,18 +170,9 @@ class sp_pcontext : public Sql_alloc
sp_pvar_t *
find_pvar(LEX_STRING *name, my_bool scoped=0);
// Find by index
sp_pvar_t *
- find_pvar(uint i)
- {
- sp_pvar_t *p;
-
- if (i < m_pvar.elements)
- get_dynamic(&m_pvar, (gptr)&p, i);
- else
- p= NULL;
- return p;
- }
+ find_pvar(uint offset);
//
// Labels
@@ -261,6 +252,10 @@ class sp_pcontext : public Sql_alloc
my_bool
find_cursor(LEX_STRING *name, uint *poff, my_bool scoped=0);
+ /* Find by offset (for debugging only) */
+ my_bool
+ find_cursor(uint offset, LEX_STRING *n);
+
inline uint
max_cursors()
{
@@ -170,18 +170,9 @@ class sp_pcontext : public Sql_alloc
sp_pvar_t *
find_pvar(LEX_STRING *name, my_bool scoped=0);
- // Find by index
+ // Find by offset
sp_pvar_t *